#!/bin/sh
#
# Init file for fastri server daemon
#
# chkconfig: 345 91 9
# description: FastRI server daemon
#
# processname: fastri-server
# config: /etc/sysconfig/fastri
# pidfile: /var/run/fastri.pid
#
### BEGIN INIT INFO
# Provides: fastri
# Required-Start: $network
# Required-Stop: $network
# Default-Start: 3 4 5
# Short-Description: FastRI server daemon
# Description: FastRI server daemon
### END INIT INFO

# source function library
. /etc/rc.d/init.d/functions

RETVAL=0

SERVER=/usr/bin/fastri-server
LOCK=/var/lock/subsys/fastri
SYSCONFIG=/etc/sysconfig/fastri
PID_FILE=/var/run/fastri.pid
DAEMON_USER=nobody

prog="fastri"

# pull in sysconfig settings
[ -f "$SYSCONFIG" ] && . "$SYSCONFIG"


start()
{
	gprintf "Starting %s:" "$prog"
	if ! [ -f "$LOG_FILE" ] && ! touch "$PID_FILE" || ! chown "$DAEMON_USER" "$PID_FILE"; then
	    failure "start"
	    RETVAL=1
	    return $RETVAL
	fi
	if ! [ -f "$LOG_FILE" ] && ! touch "$LOG_FILE" || ! chown "$DAEMON_USER" "$LOG_FILE"; then
	    failure "start"
	    RETVAL=1
	    return $RETVAL
	fi
	daemon --pidfile "$PID_FILE" --user "$DAEMON_USER" "$SERVER" "$OPTIONS"
	RETVAL=$?
	[ "$RETVAL" = 0 ] && touch "$LOCK"
	echo
}

stop()
{
	gprintf "Stopping %s:" "$prog"
	if [ -r "$PID_FILE" ]; then
	    killproc -p "$PID_FILE"
	    RETVAL=$?
	    [ "$RETVAL" = 0 ] && success "stop" || failure "stop"
	else
	    success "already stopped"
	    RETVAL=0
	fi
	[ "$RETVAL" = 0 ] && rm -f "$LOCK"
	echo
}

reload()
{
	$SERVER -b
}

case "$1" in
	start)
		start
		;;
	stop)
		stop
		;;
	reload)
		reload
		;;
	restart)
		stop
		sleep 1
		start
		;;
	condrestart)
		if [ -f "$LOCK" ] ; then
			do_restart_sanity_check
			if [ "$RETVAL" = 0 ] ; then
				stop
				# avoid race
				sleep 3
				start
			fi
		fi
		;;
	status)
		status $SERVER
		RETVAL=$?
		;;
	*)
		gprintf "Usage: %s {start|stop|restart|reload|condrestart|status}\n" "$0"
		RETVAL=1
esac
exit $RETVAL
